#
# spec file for package python-CherryPy
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-CherryPy
Version:        3.6.0
Release:        11.1
Url:            http://www.cherrypy.org
Summary:        Object-Oriented HTTP framework
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/C/CherryPy/CherryPy-%{version}.tar.gz
Patch0:         ssl_fix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
# Requires(post): update-alternatives
# Requires(postun): update-alternatives
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
%{!?py_ver:     %global py_ver     %(python -c "import sys; v=sys.version_info[:2]; print '%%d.%%d'%%v" 2>/dev/null || echo PYTHON-NOT-FOUND)}
BuildArch:      noarch
%endif
Provides:       python-cherrypy = %{version}
Obsoletes:      python-cherrypy < %{version}

%description
CherryPy is a pythonic, object-oriented HTTP framework.

CherryPy allows developers to build web applications in much the same way they
would build any other object-oriented Python program. This usually results in
smaller source code developed in less time.

CherryPy is now more than three years old and it is has proven very fast and
stable. It is being used in production by many sites, from the simplest ones
to the most demanding ones.

Oh, and most importantly: CherryPy is fun to work with :-)

%prep
%setup -q -n CherryPy-%{version}
%patch0 -p1

%build
python setup.py build

%install
sed -i 's|\r||' README.txt # Fix wrong EOL encoding
find . -name sessiondemo.py -type f -exec chmod 0755 {} \; # Fix non-executable bit rpmlint warning
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# update-alternatives
mv %{buildroot}%{_bindir}/cherryd %{buildroot}%{_bindir}/cherryd-%{py_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/cherryd
ln -sf %{_sysconfdir}/alternatives/cherryd %{buildroot}%{_bindir}/cherryd

%post
update-alternatives \
	--install %{_bindir}/cherryd cherryd %{_bindir}/cherryd-%{py_ver} 20

%postun
if [ $1 -eq 0 ] ; then
	update-alternatives --remove cherryd %{_bindir}/cherryd-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc README.txt
%ghost %{_sysconfdir}/alternatives/cherryd
%{_bindir}/cherryd
%{_bindir}/cherryd-%{py_ver}
%{python_sitelib}/cherrypy/
%{python_sitelib}/CherryPy-%{version}-py%{py_ver}.egg-info

%changelog
* Mon Jun 26 2017 jmassaguerpla@suse.com
- fix SSL not working https://github.com/cherrypy/cherrypy/issues/1298
  In order to fix SSL for salt-api for CaaSP 1.0 (bsc#1043589), we
  need to add this commit which is refered in the above github issue:
  https://github.com/cherrypy/cherrypy/commit/409d7f64e2e92e69750ac31a555c7dd859796e04
  ssl_fix.patch contains the commit.
* Sun Feb 22 2015 benoit.monin@gmx.fr
- update to version 3.6.0:
  * Fixed HTTP range headers for negative length larger than
    content size
  * Disabled universal wheel generation as wsgiserver has Python
    duality
  * Pull Request #42: Correct TypeError in ``check_auth`` when
    encrypt is used
  * Pull Request #59: Correct signature of HandlerWrapperTool
  * Pull Request #60: Fix error in SessionAuth where login_screen
    was incorrectly used
  * Issue #1077: Support keyword-only arguments in dispatchers
    (Python 3)
  * Issue #1019: Allow logging host name in the access log
  * Pull Request #50: Fixed race condition in session cleanup
- changes from version 3.5.0:
  * Issue #1301: When the incoming queue is full, now reject
    additional connections. This functionality was added to
    CherryPy 3.0, but unintentionally lost in 3.1
- changes from version 3.4.0:
  * Miscellaneous quality improvements
- remove CFLAGS export
- use update-alternatives for cherryd binary
* Tue May 20 2014 toddrme2178@gmail.com
- Update to version 3.3.0
  + No changelog available
- Update to version 3.2.6
  + No changelog available
- Update to version 3.2.5
  + No changelog available
* Thu Sep 26 2013 p.drouand@gmail.com
- Update to version 3.2.4
  + No changelog available
- Remove redundant %%clean section
* Wed May 23 2012 highwaystar.ru@gmail.com
- update to 3.2.2
- python3 package added
- minor spec improvement
* Tue May 31 2011 saschpe@suse.de
- Renamed package to python-CherryPy to match upstream PyPi name
  * Added Provides/Obsoletes for python-cherrypy
* Thu Mar  3 2011 saschpe@suse.de
- Update to 3.2:
  * WSGI-1.0.1 compliance, support for Python's builtin SSL module
  * Much improved FastCGI support
  * Python 3 support
- Spec file cleanup:
  * Added proper license header
  * Added changelog section
- Repacked tarball as tar.bz2
* Tue May 12 2009 poeml@suse.de
- the INSTALLED_FILES file name had a little typo
- fix changelog to be in chronological order (an error that I
  probably introduced during the conversion)
* Tue May 12 2009 poeml@novell.com
- add dos2unix to BuildRequires
- convert the package changelog from the in-specfile text to a .changes file,
  to be edited with "osc vc"
* Tue Mar 10 2009 James Oakley <jfunk@funktronics.ca>
- Update to 3.1.1
* Mon Jan 21 2008 James Oakley <jfunk@funktronics.ca>
- Update to 3.0.3
* Mon Aug 13 2007 James Oakley <jfunk@funktronics.ca>
- Update to 3.0.2:
  * Some bugfixes
* Tue Mar 20 2007 James Oakley <jfunk@funktronics.ca>
- Update to 3.0.1:
  * More docstrings.  help() is more helpful than ever
  * The WSGI server has been moved into its own package to allow for
    easier use outside of CherryPy
  * Session locking can now be "implicit" (before_handler), "early"
    (before_request_body), or "explicit" (none)
  * Moved checker back to cherrypy.checker from engine, and also added
    a new check_config_types method. There's also a new checker config
    namespace, so you can turn off the checker with "checker.on = False",
    or turn off specific methods with "checker.check_method_foo = None"
* Wed Jan 17 2007 Cristian Rodriguez <judas_iscariote@shorewall.net>
- Update to 3.0.0
* Thu Jun 22 2006 James Oakley <jfunk@funktronics.ca>
- Update
* Mon Oct 24 2005 James Oakley <jfunk@funktronics.ca>
- Update to final release
* Thu Oct 13 2005 James Oakley <jfunk@funktronics.ca>
- Update
- Build for SL10
* Fri Aug 12 2005 James Oakley <jfunk@funktronics.ca>
- Initial release
